==> numerous_cli-0.6.0.tar.gz: numerous_cli-0.6.0/src/numerous/cli/commands/log.py <==
from datetime import datetime
from logging import Logger
from pathlib import Path

import grpc
from dirtools import Dir, filehash
from numerous_api_client.python_protos.spm_pb2 import HistoryRequest, HistoryUpdate
from prettytable import PrettyTable

from ..auth import AuthenticationError, TokenAuth, login
from ..repository import NumerousRepository
from ..utils import bold, cyan, get_build_manager, green, red, yellow


def print_updates_table(repo: NumerousRepository, updates: list[HistoryUpdate]):
    dirty = Dir(str(repo.path)).hash(index_func=filehash) != repo.snapshot
    table = PrettyTable()
    table.field_names = ["Timestamp", "Scenario", "Comment", "Commit ID", "Current"]
    for update in updates:
        table.add_row([
            datetime.fromtimestamp(update.timestamp),
            update.scenario_id,
            update.comment,
            update.id,
            f"{green('*')} {red('dirty') if dirty else ''}" if repo.commit == update.id else ""])
    print(table)


def print_updates_git(repo: NumerousRepository, updates: list[HistoryUpdate]):
    dirty = Dir(str(repo.path)).hash(index_func=filehash) != repo.snapshot
    for update in updates:
        state = f" {green('current')}{red(' dirty') if dirty else ''}" if repo.commit == update.id else ""
        print(f"{yellow(f'commit {update.id}')} {yellow('(')}{cyan(update.project_id + ':' + update.scenario_id)}"
              f"{yellow(')')}{state}")
        update_time = datetime.fromtimestamp(update.timestamp)
        print(f"Author: {update.user.full_name} <{update.user.email}>")
        print(f'Date:   {update_time.strftime("%a %b %d %H:%M:%S %Y %z")}')
        print()
        for line in update.comment.splitlines():
            print("    " + line)
        print()


def command_log(log: Logger, path: Path, display_mode: str):
    path = path or Path.cwd()

    try:
        repo = NumerousRepository(path).load()
    except Exception as excp:
        log.debug(f"Exception {type(excp)} {excp}")
        print(red(f"Cannot get logs: {bold(str(path))} is not a repository."))
        return

    if repo.remote is None:
        print(red('Cannot get logs: No remote is configured for the repository.'))
        print(f"Use the command {bold('numbuild config --remote <REMOTE_URL>')} to configure a remote for the "
              "repository.")
        return

    if repo.scenario is None:
        print(red("Cannot get logs: A scenario must be checked out."))
        print(f"- Push to a scenario with {bold('numbuild push -c <COMMENT> <SCENARIO ID>')}")
        print(f"- Check out a scenario with {bold('numbuild checkout <SCENARIO ID>')}")
        return

    try:
        access_token = login(repo)
    except AuthenticationError:
        print(red("Cannot get logs: Login failed."))
        return
    call_credentials = grpc.metadata_call_credentials(TokenAuth(access_token))

    with get_build_manager(repo.remote.api_url) as build_manager:
        history_request = HistoryRequest(repository=repo.remote.name, scenario_id=repo.scenario.id)
        history_reply, _call = build_manager.GetHistory.with_call(history_request, credentials=call_credentials)

    if not history_reply.updates:
        print(f"No history exists for remote {bold(repo.remote)}")

    if display_mode == 'table':
        print_updates_table(repo, history_reply.updates)
    else:
        print_updates_git(repo, history_reply.updates)

==> numerous_cli-0.7.0.tar.gz: numerous_cli-0.7.0/src/numerous/cli/commands/log.py <==
from datetime import datetime
from logging import Logger
from pathlib import Path

import grpc
from dirtools import Dir, filehash
from prettytable import PrettyTable
from spm_pb2 import HistoryRequest, HistoryUpdate

from ..auth import AuthenticationError, TokenAuth, login
from ..repository import NumerousRepository
from ..utils import bold, cyan, get_build_manager, green, red, yellow


def print_updates_table(repo: NumerousRepository, updates: list[HistoryUpdate]):
    dirty = Dir(str(repo.path)).hash(index_func=filehash) != repo.snapshot
    table = PrettyTable()
    table.field_names = ["Timestamp", "Scenario", "Comment", "Commit ID", "Current"]
    for update in updates:
        table.add_row([
            datetime.fromtimestamp(update.timestamp),
            update.scenario_id,
            update.comment,
            update.id,
            f"{green('*')} {red('dirty') if dirty else ''}" if repo.commit == update.id else ""])
    print(table)


def print_updates_git(repo: NumerousRepository, updates: list[HistoryUpdate]):
    dirty = Dir(str(repo.path)).hash(index_func=filehash) != repo.snapshot
    for update in updates:
        state = f" {green('current')}{red(' dirty') if dirty else ''}" if repo.commit == update.id else ""
        print(f"{yellow(f'commit {update.id}')} {yellow('(')}{cyan(update.project_id + ':' + update.scenario_id)}"
              f"{yellow(')')}{state}")
        update_time = datetime.fromtimestamp(update.timestamp)
        print(f"Author: {update.user.full_name} <{update.user.email}>")
        print(f'Date:   {update_time.strftime("%a %b %d %H:%M:%S %Y %z")}')
        print()
        for line in update.comment.splitlines():
            print("    " + line)
        print()


def command_log(log: Logger, path: Path, display_mode: str):
    path = path or Path.cwd()

    try:
        repo = NumerousRepository(path).load()
    except Exception as excp:
        log.debug(f"Exception {type(excp)} {excp}")
        print(red(f"Cannot get logs: {bold(str(path))} is not a repository."))
        return

    if repo.remote is None:
        print(red('Cannot get logs: No remote is configured for the repository.'))
        print(f"Use the command {bold('numbuild config --remote <REMOTE_URL>')} to configure a remote for the "
              "repository.")
        return

    if repo.scenario is None:
        print(red("Cannot get logs: A scenario must be checked out."))
        print(f"- Push to a scenario with {bold('numbuild push -c <COMMENT> <SCENARIO ID>')}")
        print(f"- Check out a scenario with {bold('numbuild checkout <SCENARIO ID>')}")
        return

    try:
        access_token = login(repo)
    except AuthenticationError:
        print(red("Cannot get logs: Login failed."))
        return
    call_credentials = grpc.metadata_call_credentials(TokenAuth(access_token))

    with get_build_manager(repo.remote.api_url) as build_manager:
        history_request = HistoryRequest(repository=repo.remote.name, scenario_id=repo.scenario.id)
        history_reply, _call = build_manager.GetHistory.with_call(history_request, credentials=call_credentials)

    if not history_reply.updates:
        print(f"No history exists for remote {bold(repo.remote)}")

    if display_mode == 'table':
        print_updates_table(repo, history_reply.updates)
    else:
        print_updates_git(repo, history_reply.updates)
